Module: Google::Cloud::BareMetalSolution

Defined in:
lib/google/cloud/bare_metal_solution.rb,
lib/google/cloud/bare_metal_solution/version.rb

Constant Summary collapse

VERSION =
"2.2.0"

Class Method Summary collapse

Class Method Details

.bare_metal_solution(version: :v2, transport: :grpc, &block) ⇒ ::Object

Create a new client object for BareMetalSolution.

By default, this returns an instance of Google::Cloud::BareMetalSolution::V2::BareMetalSolution::Client for a gRPC client for version V2 of the API. However, you can specify a different API version by passing it in the version parameter. If the BareMetalSolution service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned. You can also specify a different transport by passing :rest or :grpc in the transport parameter.

Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the BareMetalSolution service. You can determine whether the method will succeed by calling bare_metal_solution_available?.

About BareMetalSolution

Performs management operations on Bare Metal Solution servers.

The baremetalsolution.googleapis.com service provides management capabilities for Bare Metal Solution servers. To access the API methods, you must assign Bare Metal Solution IAM roles containing the desired permissions to your staff in your Google Cloud project. You must also enable the Bare Metal Solution API. Once enabled, the methods act upon specific servers in your Bare Metal Solution environment.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v2)

    The API version to connect to. Optional. Defaults to :v2.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (::Object)

    A client object for the specified version.



82
83
84
85
86
87
88
89
90
91
92
# File 'lib/google/cloud/bare_metal_solution.rb', line 82

def self.bare_metal_solution version: :v2, transport: :grpc, &block
  require "google/cloud/bare_metal_solution/#{version.to_s.downcase}"

  package_name = Google::Cloud::BareMetalSolution
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::BareMetalSolution.const_get(package_name).const_get(:BareMetalSolution)
  service_module = service_module.const_get(:Rest) if transport == :rest
  service_module.const_get(:Client).new(&block)
end

.bare_metal_solution_available?(version: :v2, transport: :grpc) ⇒ boolean

Determines whether the BareMetalSolution service is supported by the current client. If true, you can retrieve a client object by calling bare_metal_solution. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the BareMetalSolution service, or if the versioned client gem needs an update to support the BareMetalSolution service.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v2)

    The API version to connect to. Optional. Defaults to :v2.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (boolean)

    Whether the service is available.



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/google/cloud/bare_metal_solution.rb', line 106

def self.bare_metal_solution_available? version: :v2, transport: :grpc
  require "google/cloud/bare_metal_solution/#{version.to_s.downcase}"
  package_name = Google::Cloud::BareMetalSolution
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  return false unless package_name
  service_module = Google::Cloud::BareMetalSolution.const_get package_name
  return false unless service_module.const_defined? :BareMetalSolution
  service_module = service_module.const_get :BareMetalSolution
  if transport == :rest
    return false unless service_module.const_defined? :Rest
    service_module = service_module.const_get :Rest
  end
  service_module.const_defined? :Client
rescue ::LoadError
  false
end

.configure {|::Google::Cloud.configure.bare_metal_solution| ... } ⇒ ::Google::Cloud::Config

Configure the google-cloud-bare_metal_solution library.

The following configuration parameters are supported:

  • credentials (type: String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.
  • lib_name (type: String) - The library name as recorded in instrumentation and logging.
  • lib_version (type: String) - The library version as recorded in instrumentation and logging.
  • interceptors (type: Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.
  • timeout (type: Numeric) - Default timeout in seconds.
  • metadata (type: Hash{Symbol=>String}) - Additional headers to be sent with the call.
  • retry_policy (type: Hash) - The retry policy. The value is a hash with the following keys:
    • :initial_delay (type: Numeric) - The initial delay in seconds.
    • :max_delay (type: Numeric) - The max delay in seconds.
    • :multiplier (type: Numeric) - The incremental backoff multiplier.
    • :jitter (type: Numeric) - The jitter in seconds. Default: 1.0.
    • :retry_codes (type: Array<String>) - The error codes that should trigger a retry.

Yields:

Returns:

  • (::Google::Cloud::Config)

    The default configuration used by this library



154
155
156
157
158
# File 'lib/google/cloud/bare_metal_solution.rb', line 154

def self.configure
  yield ::Google::Cloud.configure.bare_metal_solution if block_given?

  ::Google::Cloud.configure.bare_metal_solution
end